﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using Telerik.Windows.Controls.Map;

namespace DynamicLayerMapShapes
{
	public partial class MainPage : UserControl
	{
		public MainPage()
		{
			InitializeComponent();

			this.ReadShapes();
		}

		internal List<FrameworkElement> Shapes
		{
			get;
			private set;
		}

		private void ReadShapes()
		{
			var reader = new MapShapeReader();

			reader.PreviewReadCompleted += new PreviewReadShapesCompletedEventHandler(PreviewReadCompleted);

			reader.Read(new Uri("/DynamicLayerMapShapes;component/GeospatialData/alaska_administrative", UriKind.Relative));
		}

		private void PreviewReadCompleted(object sender, PreviewReadShapesCompletedEventArgs eventArgs)
		{
			if (eventArgs.Error == null)
			{
				this.Shapes = new List<FrameworkElement>();
				MapShapeFill polylineShapeFill = new MapShapeFill()
				{
					StrokeThickness = 1,
					Stroke = new SolidColorBrush(Colors.Black)
				};
				MapShapeFill polygonShapeFill = new MapShapeFill()
				{
					Fill = new SolidColorBrush(Color.FromArgb(0x7f, 0x5f, 0x5f, 0x9f)),
					StrokeThickness = 1,
					Stroke = new SolidColorBrush(Colors.White)
				};

				foreach (FrameworkElement element in eventArgs.Items)
				{
					MapShape shape = element as MapShape;
					if (shape != null)
					{
						var polyline = shape as MapPolyline;
						var polygon = shape as MapPolygon;
						if (polyline != null && polygon == null)
						{
							shape.ShapeFill = polylineShapeFill;
						}
						else
						{
							shape.ShapeFill = polygonShapeFill;
						}

						this.Shapes.Add(shape);
					}
				}

				DynamicSource source = new DynamicSource(this);

				const int squareWidth = 1024;
				const int squareHeight = 1024;

				for (int zoomLayerIndex = 10; zoomLayerIndex <= 15; zoomLayerIndex++)
				{
					this.dynamicLayer.ZoomGridList.Add(new ZoomGrid((int)(Math.Pow(2, zoomLayerIndex + 8) / squareWidth),
						(int)(Math.Pow(2, zoomLayerIndex + 8) / squareHeight),
						zoomLayerIndex == 15 ? 20 : zoomLayerIndex));
				}

				this.radMap.ZoomLevel = this.dynamicLayer.ZoomGridList[0].MinZoom;
				this.radMap.Center = new Location(61.5, -149);

				this.dynamicLayer.DynamicSource = source;
			}
		}
	}
}
